Module websocket

Module websocket 

Structs

BitsoWebSocket
Bitso WebSocket object.
BooksIter
SubscriptionIter

Enums

Books
Represents all the possible books available in Bitso.
Response
Represents the possible subscription responses in the Bitso WebSocket API.
Subscription
Represents the three subscription channels in the Bitso WebSocket API.

Traits

EnumCount
A trait for capturing the number of variants in Enum. This trait can be autoderived by strum_macros.
IntoEnumIterator
This trait designates that an Enum can be iterated over. It can be auto generated using strum_macros on your behalf.