Skip to main contentModule websocket
Source - BitsoWebSocket
- Bitso WebSocket object.
- BooksIter
- SubscriptionIter
- Books
- Represents all the possible books available in Bitso.
- Response
- Represents the possible subscription responses in the Bitso WebSocket API.
- Subscription
- Represents the three subscription channels in the Bitso WebSocket API.
- EnumCount
- A trait for capturing the number of variants in Enum. This trait can be autoderived by
strum_macros. - IntoEnumIterator
- This trait designates that an
Enum can be iterated over. It can
be auto generated using strum_macros on your behalf.